#!/opt/anaconda1anaconda2anaconda3\python.exe
# EASY-INSTALL-ENTRY-SCRIPT: 'conda-smithy==0.10.5','console_scripts','feedstocks'
__requires__ = 'conda-smithy==0.10.5'
import sys
from pkg_resources import load_entry_point

if __name__ == '__main__':
    sys.exit(
        load_entry_point('conda-smithy==0.10.5', 'console_scripts', 'feedstocks')()
    )
